@@ -44,7 +44,8 @@ const onConfigurationImport = async () => {
     }
 
     const data = await eel.import_configuration()();
-    importConfiguration(data);
+    // Put the config in the URL and then reload - this stops us from having to manually clear and re-validate fields
+    window.location.href = window.location.href + "?configuration=" + encodeURIComponent(JSON.stringify(data));
 };
 
 const onConfigurationExport = async () => {
